import CalculateDiscount from './discount';

export function getPortalLinkPath({page}) {
    const Links = {
        default: '#/portal',
        signin: '#/portal/signin',
        signup: '#/portal/signup',
        account: '#/portal/account',
        'account-plans': '#/portal/account/plans',
        'account-profile': '#/portal/account/profile'
    };
    if (Object.keys(Links).includes(page)) {
        return Links[page];
    }
    return Links.default;
}

export function getPortalLink({page, siteUrl}) {
    const url = siteUrl || `${window.location.protocol}//${window.location.host}${window.location.pathname}`;
    const portalLinkPath = getPortalLinkPath({page});
    return `${url}${portalLinkPath}`;
}

export function isCookiesDisabled() {
    return !(navigator && navigator.cookieEnabled);
}

export function getMemberSubscription({member = {}}) {
    if (member.paid) {
        const [subscription] = member.subscriptions || [];
        return subscription;
    }
    return null;
}

export function isComplimentaryMember({member = {}}) {
    const subscription = getMemberSubscription({member});
    if (subscription) {
        const {plan} = subscription;
        return (plan.nickname === 'Complimentary');
    }
    return false;
}

export function isPaidMember({member = {}}) {
    return (member && member.paid);
}

export function getPlanFromSubscription({subscription}) {
    if (subscription && subscription.plan) {
        return {
            type: subscription.plan.interval,
            price: subscription.plan.amount / 100,
            currency: subscription.plan.currency_symbol,
            name: subscription.plan.nickname
        };
    }
    return null;
}

export function getMemberActivePlan({member}) {
    const subscription = getMemberSubscription({member});
    return getPlanFromSubscription({subscription});
}

export function getSubscriptionFromId({member, subscriptionId}) {
    if (member.paid) {
        const subscriptions = member.subscriptions || [];
        return subscriptions.find(d => d.id === subscriptionId);
    }
    return null;
}

export function hasOnlyFreePlan({site = {}}) {
    const plans = getSitePlans({site});
    return !plans || plans.length === 0 || (plans.length === 1 && plans[0].type === 'free');
}

export function getSitePlans({site = {}, includeFree = true}) {
    const {
        plans,
        allow_self_signup: allowSelfSignup,
        is_stripe_configured: isStripeConfigured,
        portal_plans: portalPlans
    } = site || {};

    if (!plans) {
        return [];
    }

    const plansData = [];
    const discount = CalculateDiscount(plans.monthly, plans.yearly);
    const stripePlans = [
        {
            type: 'month',
            price: plans.monthly,
            currency: plans.currency_symbol,
            name: 'Monthly'
        },
        {
            type: 'year',
            price: plans.yearly,
            currency: plans.currency_symbol,
            name: 'Yearly',
            discount
        }
    ];

    if (allowSelfSignup && portalPlans.includes('free') && includeFree) {
        plansData.push({
            type: 'free',
            price: 0,
            currency: plans.currency_symbol,
            name: 'Free'
        });
    }

    if (isStripeConfigured) {
        stripePlans.forEach((plan) => {
            if (portalPlans.includes(plan.name.toLowerCase())) {
                plansData.push(plan);
            }
        });
    }
    return plansData;
}

export const getMemberEmail = ({member}) => {
    if (!member) {
        return '';
    }
    return member.email;
};

export const getMemberName = ({member}) => {
    if (!member) {
        return '';
    }
    return member.name;
};

export const getSupportAddress = ({site}) => {
    const {members_support_address: supportAddress} = site || {};
    return supportAddress || '';
};

export const createPopupNotification = ({type, status, autoHide, duration, closeable, state, message, meta}) => {
    let count = 0;
    if (state && state.popupNotification) {
        count = (state.popupNotification.count || 0) + 1;
    }
    return {
        type,
        status,
        autoHide,
        closeable,
        duration,
        meta,
        message,
        count
    };
};
